{% load get_by_id %}

### History

Page {{ history.number }} of {{ history.paginator.num_pages }}.
{% include "boards/pagination.html" with items=history %}

Date | State | Code | Response | NAMELOOKUP | CONNECT | PRETRANSFER | STARTTRANSFER | REDIRECT TIME | SIZE DOWNLOAD | SPEED DOWNLOAD | REDIRECT COUNT | CONNECTS COUNT | ARP | AGENT
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
{% for item in history %}
{{ item.created|date:"Y-m-d H:i" }} | {% if item.response_state == 1 %}OK{% elif item.response_state == 2 %}Performance{% elif item.response_state == 3 %}Serice is working incorrectly{% elif item.response_state == 4 %}Wordchecks errors{% else %}Agent fail{% endif %} | {{ item.response_code }} | {{ item.response_time|floatformat:2 }} | {{ item.namelookup_time|floatformat:2 }} | {{ item.connect_time|floatformat:2 }} | {{ item.pretransfer_time|floatformat:2 }} | {{ item.starttransfer_time|floatformat:2 }} | {{ item.redirect_time|floatformat:2 }} | {% if item.size_download %}{{ item.size_download }} B{% endif %} | {% if item.speed_download %}{{ item.speed_download }} B/s{% endif %} | {% if item.redirect_count != None %}{{ item.redirect_count }}{% endif %} | {{ item.num_connects|default:"" }} | {{ params|get_by_id:item.request_params_id }} | {{ agents|get_by_id:item.agent_id }}
{% endfor %}

{% include "boards/pagination.html" with items=history %}